@@ -81,7 +81,7 @@ var searchData=
   ['shadowformat_2eidl_78',['ShadowFormat.idl',['../ShadowFormat_8idl.html',1,'']]],
   ['shadowlocation_2eidl_79',['ShadowLocation.idl',['../ShadowLocation_8idl.html',1,'']]],
   ['shadowproperties_2eidl_80',['ShadowProperties.idl',['../ShadowProperties_8idl.html',1,'']]],
-  ['shape_2eidl_81',['Shape.idl',['../text_2Shape_8idl.html',1,'(Global Namespace)'],['../drawing_2Shape_8idl.html',1,'(Global Namespace)'],['../sheet_2Shape_8idl.html',1,'(Global Namespace)'],['../report_2Shape_8idl.html',1,'(Global Namespace)'],['../presentation_2Shape_8idl.html',1,'(Global Namespace)']]],
+  ['shape_2eidl_81',['Shape.idl',['../sheet_2Shape_8idl.html',1,'(Global Namespace)'],['../text_2Shape_8idl.html',1,'(Global Namespace)'],['../report_2Shape_8idl.html',1,'(Global Namespace)'],['../presentation_2Shape_8idl.html',1,'(Global Namespace)'],['../drawing_2Shape_8idl.html',1,'(Global Namespace)']]],
   ['shapeanimationsubtype_2eidl_82',['ShapeAnimationSubType.idl',['../ShapeAnimationSubType_8idl.html',1,'']]],
   ['shapecollection_2eidl_83',['ShapeCollection.idl',['../ShapeCollection_8idl.html',1,'']]],
   ['shapes_2eidl_84',['Shapes.idl',['../Shapes_8idl.html',1,'']]],
@@ -170,7 +170,7 @@ var searchData=
   ['standarddiagramcreationparameters_2eidl_167',['StandardDiagramCreationParameters.idl',['../StandardDiagramCreationParameters_8idl.html',1,'']]],
   ['startmodule_2eidl_168',['StartModule.idl',['../StartModule_8idl.html',1,'']]],
   ['statechangeinprogressexception_2eidl_169',['StateChangeInProgressException.idl',['../StateChangeInProgressException_8idl.html',1,'']]],
-  ['statement_2eidl_170',['Statement.idl',['../rdf_2Statement_8idl.html',1,'(Global Namespace)'],['../sdbc_2Statement_8idl.html',1,'(Global Namespace)'],['../sdbcx_2Statement_8idl.html',1,'(Global Namespace)']]],
+  ['statement_2eidl_170',['Statement.idl',['../rdf_2Statement_8idl.html',1,'(Global Namespace)'],['../sdbcx_2Statement_8idl.html',1,'(Global Namespace)'],['../sdbc_2Statement_8idl.html',1,'(Global Namespace)']]],
   ['statusbarcontroller_2eidl_171',['StatusbarController.idl',['../StatusbarController_8idl.html',1,'']]],
   ['statusbarcontrollerfactory_2eidl_172',['StatusbarControllerFactory.idl',['../StatusbarControllerFactory_8idl.html',1,'']]],
   ['statusbarfunction_2eidl_173',['StatusBarFunction.idl',['../StatusBarFunction_8idl.html',1,'']]],
@@ -191,13 +191,13 @@ var searchData=
   ['stringresourcewithlocation_2eidl_188',['StringResourceWithLocation.idl',['../StringResourceWithLocation_8idl.html',1,'']]],
   ['stringresourcewithstorage_2eidl_189',['StringResourceWithStorage.idl',['../StringResourceWithStorage_8idl.html',1,'']]],
   ['strokeattributes_2eidl_190',['StrokeAttributes.idl',['../StrokeAttributes_8idl.html',1,'']]],
-  ['style_2eidl_191',['Style.idl',['../style_2Style_8idl.html',1,'(Global Namespace)'],['../awt_2Style_8idl.html',1,'(Global Namespace)']]],
+  ['style_2eidl_191',['Style.idl',['../awt_2Style_8idl.html',1,'(Global Namespace)'],['../style_2Style_8idl.html',1,'(Global Namespace)']]],
   ['stylefamilies_2eidl_192',['StyleFamilies.idl',['../StyleFamilies_8idl.html',1,'']]],
   ['stylefamily_2eidl_193',['StyleFamily.idl',['../StyleFamily_8idl.html',1,'']]],
   ['subincrement_2eidl_194',['SubIncrement.idl',['../SubIncrement_8idl.html',1,'']]],
   ['subject_2eidl_195',['Subject.idl',['../Subject_8idl.html',1,'']]],
   ['submissionpropertyhandler_2eidl_196',['SubmissionPropertyHandler.idl',['../SubmissionPropertyHandler_8idl.html',1,'']]],
-  ['submitbutton_2eidl_197',['SubmitButton.idl',['../control_2SubmitButton_8idl.html',1,'(Global Namespace)'],['../component_2SubmitButton_8idl.html',1,'(Global Namespace)']]],
+  ['submitbutton_2eidl_197',['SubmitButton.idl',['../component_2SubmitButton_8idl.html',1,'(Global Namespace)'],['../control_2SubmitButton_8idl.html',1,'(Global Namespace)']]],
   ['subtitleshape_2eidl_198',['SubtitleShape.idl',['../SubtitleShape_8idl.html',1,'']]],
   ['subtotalcolumn_2eidl_199',['SubTotalColumn.idl',['../SubTotalColumn_8idl.html',1,'']]],
   ['subtotaldescriptor_2eidl_200',['SubTotalDescriptor.idl',['../SubTotalDescriptor_8idl.html',1,'']]],
